@@ -11,13 +11,12 @@ import random
 import time
 import os
 from .config import Config
-
+from .utils import market_fig, market_candlestick
 try:
     import ujson as json
 except ModuleNotFoundError:
     import json
 
-
 global_config = nonebot.get_driver().config
 russian_config = Config.parse_obj(global_config.dict())
 
@@ -46,7 +45,6 @@ russian_config = Config.parse_obj(nonebot.get_driver().config.dict())
 max_bet_gold = russian_config.max_bet_gold
 race_bet_gold = russian_config.race_bet_gold
 
-
 async def rank(player_data: dict, group_id: int, type_: str) -> str:
     """
     排行榜数据统计
@@ -145,7 +143,6 @@ class GameManager:
         self._current_player = {}
         file = russian_path / "data" / "russian" / "russian_data.json"
         self.file = file
-        file.parent.mkdir(exist_ok=True, parents=True)
         if not file.exists():
             old_file = Path(os.path.dirname(__file__)) / "russian_data.json"
             if old_file.exists():
@@ -193,12 +190,11 @@ class GameManager:
         :param event: event
         """
         self._init_player_data(event)
-        try:
-            if self._current_player[event.group_id][1] == 0:
-                return None
-        except KeyError:
+        if not self._current_player.get(event.group_id):
             return None
-        if (
+        elif self._current_player[event.group_id][1] == 0:
+            return None
+        elif (
             self._current_player[event.group_id][1] == event.user_id or self._current_player[event.group_id][2] != 0 or 
             self._current_player[event.group_id]["at"] != 0 and self._current_player[event.group_id]["at"] != event.user_id
             ):
@@ -218,9 +214,9 @@ class GameManager:
                     return None
 
                 if self._player_data[str(event.group_id)][str(event.user_id)]["gold"] < money:
-                    return "你的金币不足以接受这场对决！"
+                    return Message(MessageSegment.at(event.user_id) + "你的金币不足以接受这场对决！")
                 else:
-                    player2_name = event.sender.card if event.sender.card else event.sender.nickname
+                    player2_name = event.sender.card or event.sender.nickname
                     self._current_player[event.group_id][2] = event.user_id
                     self._current_player[event.group_id]["player2"] = player2_name
                     self._current_player[event.group_id]["time"] = time.time()
@@ -250,7 +246,7 @@ class GameManager:
                             "——————————————\n"
                             f'玩家：{self._current_player[event.group_id]["player2"]}\n'
                             "状态：\n"
-                            f'HP 20  SP 5  DEF 0\n'
+                            f'HP 25  SP 2  DEF 0\n'
                             "——————————————\n"
                             f'当前回合：{self._current_player[event.group_id]["player1"]}\n'
                             "手牌：\n"
@@ -268,12 +264,11 @@ class GameManager:
         :param event: event
         """
         self._init_player_data(event)
-        try:
-            if self._current_player[event.group_id][1] == 0:
-                return None
-        except KeyError:
+        if not self._current_player.get(event.group_id):
             return None
-        if self._current_player[event.group_id]["at"] == event.user_id:
+        elif self._current_player[event.group_id][1] == 0:
+            return None
+        elif self._current_player[event.group_id]["at"] == event.user_id:
             self._current_player[event.group_id] = {}
             return "拒绝成功，对决已结束。"
         else:
@@ -285,12 +280,16 @@ class GameManager:
         :param event: event
         """
         self._init_player_data(event)
-        if (
+        if not self._current_player.get(event.group_id):
+            return None
+        elif self._current_player[event.group_id][1] == 0:
+            return None
+        elif (
             self._current_player[event.group_id][1] != 0 and
             self._current_player[event.group_id][2] != 0 and
             time.time() - self._current_player[event.group_id]["time"] > 30
             ):
-            if self._current_player[event.group_id]["game"] == "russian":
+            if self._current_player[event.group_id]["game"] in ("russian","poker"):
                 win_name = (
                     self._current_player[event.group_id]["player1"]
                     if self._current_player[event.group_id][2] == self._current_player[event.group_id]["next"]
@@ -310,7 +309,12 @@ class GameManager:
         结束游戏
         :param event: event
         """
-        if (
+        self._init_player_data(event)
+        if not self._current_player.get(event.group_id):
+            return None
+        elif self._current_player[event.group_id][1] == 0:
+            return None
+        elif (
             self._current_player[event.group_id]["game"] == "dice" and
             event.user_id == self._current_player[event.group_id]["lose"] and
             event.user_id == self._current_player[event.group_id]["next"]
@@ -402,7 +406,7 @@ class GameManager:
                     "dice_array1":random_dice(),
                     "dice_array2":random_dice(),
                     "win":event.user_id,
-                    "win_name":"player1_name",
+                    "win_name":player1_name,
                     "lose":0,
                     "lose_name":"",
                     } 
@@ -436,10 +440,10 @@ class GameManager:
                         },
                     "status2":{
                         "hand":[],
-                        "HP":20,
+                        "HP":25,
                         "ATK":0,
                         "DEF":0,
-                        "SP":5
+                        "SP":2
                         }
                     } 
                 )
@@ -856,8 +860,7 @@ class GameManager:
                 if (
                     self._current_player[event.group_id]["status1"]["HP"] < 1 
                     or self._current_player[event.group_id]["status2"]["HP"]  < 1
-                    or self._current_player[event.group_id]["status1"]["HP"]  > 40
-                    or self._current_player[event.group_id]["status2"]["HP"]  > 40
+                    or st2["HP"]  > 40
                     or [0,0] in hand
                     ):
                     next_name = "游戏结束"
@@ -891,6 +894,8 @@ class GameManager:
                 self._current_player[event.group_id]["act"] = 1
                 if next_name == "游戏结束":
                     self._current_player[event.group_id]["act"] = 0
+                    if st2["HP"]  > 40:
+                        st2["HP"] += 100
                     await asyncio.sleep(0.5)
                     await self.end_game(bot, event)
             else:
@@ -982,21 +987,23 @@ class GameManager:
 
     def reset_gold(self):
         """
-        重置签到
+        刷新签到
         """
         for group in self._player_data.keys():
             for user_id in self._player_data[group].keys():
                 self._player_data[group][user_id]["is_sign"] = False
-        self.save()
+        else:
+            self.save()
 
     def reset_security(self):
         """
-        重置补贴
+        刷新补贴
         """
         for group in self._player_data.keys():
             for user_id in self._player_data[group].keys():
                 self._player_data[group][user_id]["security"] = 0
-        self.save()
+        else:
+            self.save()
 
     def interest(self):
         """
@@ -1005,8 +1012,11 @@ class GameManager:
         for group in self._player_data.keys():
             for user_id in self._player_data[group].keys():
                 if self._player_data[group][user_id]["gold"] > 0:
-                    self._player_data[group][user_id]["gold"] = int(self._player_data[group][user_id]["gold"] * 1.02)
-        self.save()
+                    IN = int(self._player_data[group][user_id]["gold"] * 0.02)
+                    self._player_data[group][user_id]["gold"] += IN
+                    self._player_data[group][user_id]["make_gold"] += IN
+        else:
+            self.save()
 
     def save(self):
         """
@@ -1022,7 +1032,7 @@ class GameManager:
         """
         user_id = str(event.user_id)
         group_id = str(event.group_id)
-        nickname = event.sender.card if event.sender.card else event.sender.nickname
+        nickname = event.sender.card or event.sender.nickname
         if group_id not in self._player_data.keys():
             self._player_data[group_id] = {}
         if user_id not in self._player_data[group_id].keys():
@@ -1079,21 +1089,19 @@ class GameManager:
         elif self._current_player[event.group_id]["game"] == "poker":
             if self._current_player[event.group_id]["status1"]["HP"] > self._current_player[event.group_id]["status2"]["HP"]:
                 win_user_id = self._current_player[event.group_id][1]
-                win_name = player1_name
                 lose_user_id = self._current_player[event.group_id][2]
+                win_name = player1_name
                 lose_name = player2_name
             else:
                 win_user_id = self._current_player[event.group_id][2]
-                win_name = player2_name
                 lose_user_id = self._current_player[event.group_id][1]
+                win_name = player2_name
                 lose_name = player1_name
         else:
             pass
 
         flag = self._player_data[str(event.group_id)][str(win_user_id)]["props"].get("钻石会员卡",0)
-
         gold = self._current_player[event.group_id]["money"]
-
         if flag > 0:
             rand = -1
             fee = 0
@@ -1284,7 +1292,7 @@ class GameManager:
         user_id = str(at_player_id)
         group_id = str(event.group_id)
         at_player_data = await bot.get_group_member_info(group_id=event.group_id, user_id=at_player_id)
-        nickname = at_player_data["card"] if at_player_data["card"] else at_player_data["nickname"]
+        nickname = at_player_data["card"] or at_player_data["nickname"]
         if group_id not in self._player_data.keys():
             self._player_data[group_id] = {}
             self.save()
@@ -1465,10 +1473,18 @@ class SingleManager:
                     if russian_manager._player_data[group_id][user_id]["props"]["20%额外奖励"] < 7:
                         russian_manager._player_data[group_id][user_id]["props"]["20%额外奖励"] += 1
                     msg += "『20%额外奖励』 ☆☆☆☆☆\n"
+                elif props in range(51,56):
+                    msg += "『进口空气』 ☆☆☆☆☆\n"
+                elif props in range(56,61):
+                    msg += "『特级空气』 ☆☆☆☆☆\n"
+                elif props in range(61,81):
+                    msg += "『优质空气』 ☆☆☆\n"
                 elif props == 100:
                     russian_manager._player_data[group_id][user_id]["props"].setdefault("钻石",0)
                     russian_manager._player_data[group_id][user_id]["props"]["钻石"] += 1
                     msg += "『钻石』 ☆☆☆☆☆☆\n"
+                elif props == 200:
+                    msg += "『纯净空气』 ☆☆☆☆☆☆\n"
                 else:
                     msg += "『空气』 ☆\n"
                     pass
@@ -1487,12 +1503,9 @@ class MarketManager:
 
     def __init__(self):
         self._market_data = {}
-        # 市场指数
-        self.market_index = {}
-
+        self.market_index = {}  # 市场指数
         file = russian_path / "data" / "russian" / "market_data.json"
-        self.file = file
-        file.parent.mkdir(exist_ok=True, parents=True)
+        self.market_index_file = file
         if not file.exists():
             old_file = Path(os.path.dirname(__file__)) / "market_data.json"
             if old_file.exists():
@@ -1502,10 +1515,8 @@ class MarketManager:
                 self._market_data = json.load(f)
 
         self.Stock_Exchange = {}
-
         file = russian_path / "data" / "russian" / "Stock_Exchange.json"
         self.Stock_Exchange_file = file
-        file.parent.mkdir(exist_ok=True, parents=True)
         if not file.exists():
             old_file = Path(os.path.dirname(__file__)) / "Stock_Exchange.json"
             if old_file.exists():
@@ -1514,6 +1525,17 @@ class MarketManager:
             with open(file, "r", encoding="utf8") as f:
                 self.Stock_Exchange = json.load(f)
 
+        self.market_history = {}
+        file = russian_path / "data" / "russian" / "market_history.json"
+        self.market_history_file = file
+        if not file.exists():
+            old_file = Path(os.path.dirname(__file__)) / "market_history.json"
+            if old_file.exists():
+                os.rename(old_file, file)
+        if file.exists():
+            with open(file, "r", encoding="utf8") as f:
+                self.market_history = json.load(f)
+
     def _init_market_data(self, event: GroupMessageEvent,company_name: str):
         """
         初始化市场数据
@@ -1548,16 +1570,23 @@ class MarketManager:
         """
         保存市场数据
         """
-        with open(self.file, "w", encoding="utf8") as f:
+        with open(self.market_index_file, "w", encoding="utf8") as f:
             json.dump(self._market_data, f, ensure_ascii=False, indent=4)
 
-    def Stock_Exchange_data_save(self):
+    def Stock_Exchange_save(self):
         """
         保存交易数据
         """
         with open(self.Stock_Exchange_file, "w", encoding="utf8") as f:
             json.dump(self.Stock_Exchange, f, ensure_ascii=False, indent=4)
 
+    def market_history_save(self):
+        """
+        保存市场历史数据
+        """
+        with open(self.market_history_file, "w", encoding="utf8") as f:
+            json.dump(self.market_history, f, ensure_ascii=False, indent=4)
+
     def Market_sell(self, event: GroupMessageEvent, company_name: str, quote:float, stock:int) -> str:
         """
         市场卖出
@@ -1580,7 +1609,7 @@ class MarketManager:
             self.Stock_Exchange[company_name][user_id]["quote"] = quote
             self.Stock_Exchange[company_name][user_id]["stock"] = stock
             self.Stock_Exchange[company_name][user_id]["group_id"] = group_id
-            self.Stock_Exchange_data_save()
+            self.Stock_Exchange_save()
             return (
                 f"【{company_name}】\n"
                 "——————————————\n"
@@ -1598,7 +1627,7 @@ class MarketManager:
                     "group_id":group_id
                     }
                 )
-            self.Stock_Exchange_data_save()
+            self.Stock_Exchange_save()
             return (
                 f"【{company_name}】\n"
                 "——————————————\n"
@@ -1678,7 +1707,7 @@ class MarketManager:
                         count += TL[lst[i][0]][1]
                     else:
                         russian_manager.save()
-                        self.Stock_Exchange_data_save()
+                        self.Stock_Exchange_save()
                         return (
                             "交易成功！\n"
                             "——————————————\n"
@@ -1707,7 +1736,7 @@ class MarketManager:
                 self._market_data[company_name]["float_gold"] = gold * 0.5
                 self.market_data_save()
                 self.Stock_Exchange.setdefault(company_name,{})
-                self.Stock_Exchange_data_save()
+                self.Stock_Exchange_save()
                 return f'{company_name}发行成功，发行价格为每股{round((self._market_data[company_name]["gold"]/20000),2)}金币'
 
     def company_buy(self,event: GroupMessageEvent, company_name:str ,stock:int) -> str:
@@ -1731,11 +1760,9 @@ class MarketManager:
                 for i in range(stock):
                     tmp = _gold/ 20000
                     tmp = 0.1 if tmp < 0.1 else tmp
-                    _gold += tmp
+                    _gold += tmp * 0.65
                     value += tmp
                 else:
-                    value = value * 1.002
-
                     if value > my_gold:
                         return (
                             "你的金币不足...\n"
@@ -1756,11 +1783,10 @@ class MarketManager:
                         gold = self._market_data[company_name]["gold"]
                         group_gold = self._market_data[company_name]["group_gold"]
                         float_gold = self._market_data[company_name]["float_gold"]
-                        self._market_data[company_name]["float_gold"] = float_gold * 0.5 + group_gold * 0.1 + gold * 0.3
+                        self._market_data[company_name]["float_gold"] = float_gold * 0.4 + group_gold * 0.15 + gold * 0.3
                         russian_manager._player_data[group_id][user_id]["stock"]["value"] = self.value_update(group_id,user_id)
                         self.market_data_save()
                         russian_manager.save()
-
                         return (
                             "交易成功！\n"
                             "——————————————\n"
@@ -1796,19 +1822,18 @@ class MarketManager:
             _gold = company["float_gold"]
             for i in range(stock):
                 tmp = float(_gold/ 20000)
-                _gold -= tmp
+                _gold -= tmp * 0.65
                 value += tmp
             else:
-                value = value * 0.998
                 self._market_data[company_name]["stock"] += stock
                 russian_manager._player_data[group_id][user_id]["stock"][company_name] -= stock
                 self._market_data[company_name]["gold"] -= value
-                russian_manager._player_data[group_id][user_id]["gold"] += int(value)
+                russian_manager._player_data[group_id][user_id]["gold"] += int(value * 0.998)
                 self._market_data[company_name]["group_gold"] = float(russian_manager.total_gold(str(self._market_data[company_name]["group_id"]),1000))
                 gold = self._market_data[company_name]["gold"]
                 group_gold = self._market_data[company_name]["group_gold"]
                 float_gold = self._market_data[company_name]["float_gold"]
-                self._market_data[company_name]["float_gold"] = float_gold * 0.5 + group_gold * 0.1 + gold * 0.3
+                self._market_data[company_name]["float_gold"] = float_gold * 0.4 + group_gold * 0.15 + gold * 0.3
                 russian_manager._player_data[group_id][user_id]["stock"]["value"] = self.value_update(group_id,user_id)
                 self.market_data_save()
                 russian_manager.save()
@@ -1818,7 +1843,7 @@ class MarketManager:
                     f"【{company_name}】\n" 
                     f"数量：{stock}\n"
                     f"单价：{round(value/stock,2)}\n"
-                    f"总计：{int(value)}"
+                    f"总计：{int(value * 0.998)}"
                     )
 
     def cheak_market(self,company_name:str,user_id:str) -> bool:
@@ -1832,7 +1857,7 @@ class MarketManager:
                 return True
         return False
 
-    def Market_info_(self, event, company_name:str):
+    def Market_info(self, event, company_name:str):
         """
         市场信息
         :param company_name:公司名，为空则是总览。
@@ -1863,64 +1888,129 @@ class MarketManager:
             
             msg_lst = []
             n = len(lst)
+            if n:
+                for i in range(n):
+                    price = (
+                        self._market_data[lst[i][0]]["gold"]
+                        if self._market_data[lst[i][0]]["gold"] > self._market_data[lst[i][0]]["float_gold"]
+                        else self._market_data[lst[i][0]]["float_gold"]
+                        )
+                    msg_lst.append(
+                        f'【{lst[i][0]}】\n'
+                        "——————————————\n"
+                        f'固定资产：{round(self._market_data[lst[i][0]]["gold"], 2)} 金币\n'
+                        f'市场流动：{int(lst[i][1])} 金币\n'
+                        f'发行价格：{round(price/20000,2)} 金币\n'
+                        f'结算价格：{round(self._market_data[lst[i][0]]["float_gold"] / 20000, 2)} 金币\n'
+                        f'剩余数量：{self._market_data[lst[i][0]]["stock"]} 株\n'
+                        "——————————————"
+                        )
+                else:
+                    if market_info_chain == False or isinstance(event, PrivateMessageEvent):
+                        for i in range(n):
+                            msg += msg_lst[i] + "\n"
+                        else:
+                            msg = msg[:-1]
+                            if market_info_type == "image":
+                                output = BytesIO()
+                                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                                msg = MessageSegment.image(output)
+                            else:
+                                msg = msg.replace("——————————————", "----------")
+                    else:
+                        msg = []
+                        if market_info_type == "image" :
+                            for i in range(n):
+                                output = BytesIO()
+                                Text2Image.from_text(msg_lst[i],50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                                msg.append(
+                                    {
+                                        "type": "node",
+                                        "data": {
+                                            "name": f"{bot_name}",
+                                            "uin": str(event.self_id),
+                                            "content": MessageSegment.image(output)
+                                            }
+                                        }
+                                    )
+                        else:
+                            for i in range(n):
+                                msg.append(
+                                    {
+                                        "type": "node",
+                                        "data": {
+                                            "name": f"{bot_name}",
+                                            "uin": str(event.self_id),
+                                            "content": msg_lst[i]
+                                            }
+                                        }
+                                    )
+            else:
+                msg = "市场不存在..."
+        return msg
 
+    def Market_info_pro(self, event):
+        """
+        市场详细信息
+        """
+        lst = []
+        for x in self._market_data.keys():
+            if self._market_data[x].get("time") == None:
+                lst.append([x,self._market_data[x]["group_gold"]])
+        else:
+            lst.sort(key = lambda x:x[1],reverse = True)
+
+        n = len(lst)
+        if n:
             for i in range(n):
                 price = (
                     self._market_data[lst[i][0]]["gold"]
                     if self._market_data[lst[i][0]]["gold"] > self._market_data[lst[i][0]]["float_gold"]
                     else self._market_data[lst[i][0]]["float_gold"]
                     )
-                msg_lst.append(
-                    f'【{lst[i][0]}】\n'
-                    "——————————————\n"
-                    f'固定资产：{round(self._market_data[lst[i][0]]["gold"], 2)} 金币\n'
-                    f'市场流动：{int(lst[i][1])} 金币\n'
-                    f'发行价格：{round(price/20000,2)} 金币\n'
-                    f'结算价格：{round(self._market_data[lst[i][0]]["float_gold"] / 20000, 2)} 金币\n'
-                    f'剩余数量：{self._market_data[lst[i][0]]["stock"]} 株\n'
-                    "——————————————"
+                msg.append(
+                    {
+                        "type": "node",
+                        "data": {
+                            "name": f"{bot_name}",
+                            "uin": str(event.self_id),
+                            "content": (
+                                f'【{lst[i][0]}】\n'
+                                "——————————————\n"
+                                f'固定资产：{round(self._market_data[lst[i][0]]["gold"], 2)} 金币\n'
+                                f'市场流动：{int(lst[i][1])} 金币\n'
+                                f'发行价格：{round(price/20000,2)} 金币\n'
+                                f'结算价格：{round(self._market_data[lst[i][0]]["float_gold"] / 20000, 2)} 金币\n'
+                                f'剩余数量：{self._market_data[lst[i][0]]["stock"]} 株\n'
+                                "——————————————"
+                                ) 
+                            }
+                        }
+                    )
+                msg.append(
+                    {
+                        "type": "node",
+                        "data": {
+                            "name": f"{bot_name}",
+                            "uin": str(event.self_id),
+                            "content": MessageSegment.image(market_fig(self.market_history[lst[i][0]],lst[i][0]))
+                            }
+                        }
+                    )
+                msg.append(
+                    {
+                        "type": "node",
+                        "data": {
+                            "name": f"{bot_name}",
+                            "uin": str(event.self_id),
+                            "content": MessageSegment.image(market_candlestick(self.market_history[lst[i][0]],lst[i][0]))
+                            }
+                        }
                     )
             else:
-                if market_info_chain == False or isinstance(event, PrivateMessageEvent):
-                    for i in range(n):
-                        msg += msg_lst[i] + "\n"
-                    else:
-                        msg = msg[:-1]
-                        if market_info_type == "image":
-                            output = BytesIO()
-                            Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-                            msg = MessageSegment.image(output)
-                        else:
-                            msg = msg.replace("——————————————", "----------")
-                else:
-                    msg = []
-                    if market_info_type == "image" :
-                        for i in range(n):
-                            output = BytesIO()
-                            Text2Image.from_text(msg_lst[i],50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-                            msg.append(
-                                {
-                                    "type": "node",
-                                    "data": {
-                                        "name": f"{bot_name}",
-                                        "uin": str(event.self_id),
-                                        "content": MessageSegment.image(output)
-                                        }
-                                    }
-                                )
-                    else:
-                        for i in range(n):
-                            msg.append(
-                                {
-                                    "type": "node",
-                                    "data": {
-                                        "name": f"{bot_name}",
-                                        "uin": str(event.self_id),
-                                        "content": msg_lst[i]
-                                        }
-                                    }
-                                )
-        return msg
+                return msg
+        else:
+            return "市场不存在..."
 
     def company_info(self,company_name:str):
         """
@@ -2012,7 +2102,14 @@ class MarketManager:
             + gold * 0.3 # 固定资产
             )
 
-        self.market_data_save()
+        # 记录历史价格
+        buy = self._market_data[company_name]["gold"] / 20000
+        sell = self._market_data[company_name]["float_gold"] / 20000
+
+        self.market_history.setdefault(company_name,[])
+        self.market_history[company_name].append([time.time(),buy,sell])
+        while len(self.market_history[company_name]) > 2100:
+            del self.market_history[company_name][0]
 
     def intergroup_transfer(self, event, company_name, gold) -> str:
         """
@@ -2036,7 +2133,7 @@ class MarketManager:
             if flag > 0:
                 fee = 0
             else:
-                fee = int(gold * 0.02)
+                fee = int(gold * 0.01)
 
             russian_manager._player_data[company_id][user_id]["gold"] += gold - fee
             russian_manager._player_data[group_id][user_id]["gold"] -= gold
@@ -2044,12 +2141,11 @@ class MarketManager:
             
             return (
                 f"向 【{company_name}】 转移 {gold}金币\n"+
-                ("『钻石会员卡』免手续费" if flag > 0 else f"扣除2%手续费：{fee}，实际到账金额{gold - fee}")
+                ("『钻石会员卡』免手续费" if flag > 0 else f"扣除1％手续费：{fee}，实际到账金额{gold - fee}")
                 )
         else:
             return f"【{company_name}】未注册"
 
 
 
-
 market_manager = MarketManager()
